import Taro from '@tarojs/taro'
import { View, Text } from '@tarojs/components'
import Pay from '@/assets/icons/housemantj/pay.png'
import { getQueryString } from '@/utils/index'
import CouponCard from '@/components/CouponCard'
import { compressImage } from '@/utils'
import Location from '@/components/Location'
import SaveIcon from '@/components/SaveIcon'

import './style.less'

const CouponMedia = CouponCard.Media
const Action = CouponCard.Action

export default (props) => {

  const { item, st, taRoomContent, trackClick, det } = props
  const { shopId, packageId } = props.item

  const goFood = () => {
    trackClick({ eventType: 'hotel_recommend_package', eventParams: getQueryString({ hotelId: taRoomContent.hotelId, shopId: shopId, packageId: packageId }) })
    Taro.navigateTo({ url: `/pages/details/foodDetails/foodDetails?id=${shopId}` })
  }

  const handlePayClick = () => {
    Taro.navigateTo({ url: `/pages/PayOrder/index?packageId=${item.packageId}` })
  }

  const PayAction = <Action.Icon icon={Pay} text='支付' onClick={handlePayClick} />

  return (
    <CouponCard action={PayAction}>
      <CouponMedia onClick={goFood}>
        <CouponMedia.Header
          cashback={item.cashback}
          image={compressImage(item.poster, 'thumb')}
          badge='food'
        />
        <CouponMedia.Body star={st}>
          <View className='bossCard'>
            <View className='cpn-card-text'>
              {(item.description).toString().length > 25 ? (item.description).substring(0, 25) + '...' : (item.description)}
            </View>
            <View className='cpn-card-text' style={{ marginTop: '10rpx' }}>
              <Text className='cpn-card-text_mn'>￥{`${(item.actualPrice / 100)?.toFixed(2)}元`}</Text>
              <Text className='cpn-card-text_rm'>{`门市价${(item.standardPrice / 100)?.toFixed(2)}元`}</Text>
            </View>
            <View className='cpn-md-act'>
              <Location {...det} />
              <SaveIcon saved={item.isSaved > 0} targetType='shop_package' targetId={item.packageId} />
            </View>
          </View>
        </CouponMedia.Body>
      </CouponMedia>
    </CouponCard>
  )
}
