import Taro from "@tarojs/taro";
import { View, Text } from '@tarojs/components'
import { compressImage } from '@/utils'
import { parseQueryString } from '@/utils/index'
import formatTime from "@/utils/formatTime";
import SlideView from '@/components/SlideView';
import CouponCard from '@/components/CouponCard'
import { getQrcode } from '@/services/miniapp'
import QRcode from "@/assets/icons/UserCenter/QRcode.png";
import refund from "@/assets/icons/GuideCheck/refund.png";
import Cancel from "@/assets/icons/UserCenter/Cancel.png";
import Pay from "@/assets/icons/housemantj/pay.png";
import Null from "@/assets/icons/UserCenter/null_logo.png";
import Evaluated from "@/assets/icons/UserCenter/evaluated.png";
import Refund from "@/assets/icons/UserCenter/Refund.png";
import Evaluation from "@/assets/icons/UserCenter/Evaluation.png";
import './style.less'


const CouponMedia = CouponCard.Media
const Action = CouponCard.Action

export default (props) => {
  const { item, setShowCutover, show, sh, kkp, handeDelete } = props

  const handleDetail = () => {
    if (item.status === 0) {
      Taro.navigateTo({
        url: `/pages/PayOrder/index?orderId=${item.orderId}`,
      });
    }
  }

  //核销
  const onWriteOff = (item) => {
    Taro.scanCode({
      onlyFromCamera: true,
      success: (res) => {
        if (res.path) {
          getQrcode(parseQueryString(res.path.split('?')[1]).scene).then((res2) => {
            const maid = res2.scene.split('=')[1].split('&')[0] //二维码的商铺id
            if (maid == item.shopId) {
              Taro.navigateTo({
                url: `/${res.path}&subOrderId=${item.subOrderId}`,
              });
            } else {
              Taro.showToast({
                title: "非套餐对应店铺二维码",
                icon: "none",
                duration: 2000,
              });
            }
          })

        } else {
          Taro.showToast({
            title: "非当前小程序生成二维码",
            icon: "none",
            duration: 2000,
          });
        }
      },
      fail: (err) => {
      },
    });
  }
  //评价
  const evaluation = (val) => {
    show(val)
    setShowCutover(true)
  }
  //售后
  const handleRefund = (item) => {
    Taro.navigateTo({
      url: `/pages/MineUserAll/RefundMoney/CheckRefund/index?id=${item.orderId}`,
    });
  };


  let PayAction = null
  if (kkp == '1') {//空卡片用于售后详情页面
    PayAction = null
  } else if (sh == '1') {//售后页面卡片
    PayAction = <Action.Icon icon={Refund} text='售后/退款' onClick={() => handleRefund(item)} />
  } else if (item.status === 0) {//待支付
    PayAction = <Action.Icon icon={Pay} text='支付' onClick={handleDetail} />
  } else if (item.status === 1 && item.isVerified == false) {//待核销
    PayAction = <Action.Icon icon={QRcode} text='扫码核销' onClick={() => onWriteOff(item)} />
  } else if (item.status === 2 && item.isVerified == false) {//已退费
    PayAction = <Action.Image image={refund} />
  } else if (item.status === 7 && item.isVerified == false) {//已取消
    PayAction = <Action.Image image={Cancel} />
  } else if (item.status === 9) {//已过期
    PayAction = <Action.Image image={Null} />
  } else if (item.isVerified == true && item.isEvaluated > 0) {//已评价
    PayAction = <Action.Image image={Evaluated} />
  } else if (item.isVerified == true) {//待评价
    PayAction = <Action.Icon icon={Evaluation} text='评价' onClick={() => evaluation(item)} />
  } else {
    PayAction = null
  }

  return (
    <>
      {
        //售后和售后详情页面不显示订单编号
        sh != '1' || kkp != '1' ? <view className='OrderNumber'>订单编号：{item.orderId}</view> : null
      }
      {
        //待支付可以左滑删除
        item.status === 0 ? <SlideView del onDelete={() => handeDelete(item)} className='dzf'>
          <CouponCard onClick={() => { Taro.navigateTo({ url: `/pages/details/foodDetails/foodDetails?id=${item.shopId}` }) }} action={PayAction}>
            <CouponMedia>
              <CouponMedia.Header
                cashback={item.cashback}
                image={compressImage(item.poster)}
                badge='food'
              />
              <CouponMedia.Body star={kkp == '1' ? 'ss' : item.score}>
                <View className='orderCard'>
                  <View className='cpn-card-text'>
                    <View style={{ flex: '1' }}>{(item.packageDescription).toString().length > 25 ? (item.packageDescription).substring(0, 25) + '...' : (item.packageDescription)}</View>
                    <text className={kkp == '1' ? 'shanchu' : 'title-money-2'}>
                      数量：{item.amount}张
                    </text>
                  </View>
                  <View className='cpn-card-text' style={{ marginTop: '10rpx' }}>
                    <Text className='cpn-card-text_mn'>￥{`${(item.unitPrice / 100)?.toFixed(2)}元`}</Text>
                  </View>
                  <View className='cpn-md-act'>
                    <view className={item.isVerified == 1 ? 'title-time' : ''}>
                      {
                        sh == 1 ? '有效期：' + formatTime(item.endTime, "yyyy/MM/dd") :
                          item.isVerified == 1 ? '' + formatTime(item?.verifiedDate, "yyyy/MM/dd hh:mm:ss") :
                            '有效期：' + formatTime(item?.startTime, "yyyy/MM/dd") + '-' +
                            formatTime(item.endTime, "yyyy/MM/dd")
                      }
                    </view>
                  </View>
                </View>
              </CouponMedia.Body>
            </CouponMedia>
          </CouponCard>
        </SlideView>
          :
          <CouponCard onClick={() => { Taro.navigateTo({ url: `/pages/details/foodDetails/foodDetails?id=${item.shopId}` }) }} action={PayAction} >
            <CouponMedia>
              <CouponMedia.Header
                cashback={item.cashback}
                image={compressImage(item.poster)}
                badge='food'
              />
              <CouponMedia.Body star={kkp == '1' ? 'ss' : item.score}>
                <View className='orderCard'>
                  <View className='cpn-card-text'>
                    <View style={{ flex: '1' }}>{(item.packageDescription).toString().length > 25 ? (item.packageDescription).substring(0, 25) + '...' : (item.packageDescription)}</View>
                    <text className={kkp == '1' ? 'shanchu' : 'title-money-2'}>
                      数量：{item.amount}张
                    </text>
                  </View>
                  <View className='cpn-card-text' style={{ marginTop: '10rpx' }}>
                    <Text className='cpn-card-text_mn'>￥{`${(item.unitPrice / 100)?.toFixed(2)}元`}</Text>
                  </View>
                  <View className='cpn-md-act'>
                    <view className={item.isVerified == 1 ? 'title-time' : ''}>
                      {
                        sh == 1 ? '有效期：' + formatTime(item.endTime, "yyyy/MM/dd") :
                          item.isVerified == 1 ? '' + formatTime(item?.verifiedDate, "yyyy/MM/dd hh:mm:ss") :
                            '有效期：' + formatTime(item?.startTime, "yyyy/MM/dd") + '-' +
                            formatTime(item.endTime, "yyyy/MM/dd")
                      }
                    </view>
                  </View>
                </View>
              </CouponMedia.Body>
            </CouponMedia>
          </CouponCard>
      }

    </>

  )
}