import React, { useState, useEffect } from "react";
import Taro, { useDidShow } from "@tarojs/taro";
import { getOrderSub, deleteOrder } from "@/services/payOrder";
import NoData from '@/components/NoData'
import SpinBox from "@/components/Spin/SpinBox";
import AlreadyUsed from "../AlreadyUsed";
import OrderCard from '../OrderCard'
import "./style.less";

const dict = {
  0: { status: 0, isVerified: 0 },
  1: { status: 1, isVerified: 0 },
  2: { isVerified: 1 },
  3: { status: 9, isVerified: 0 },
};
export default (props) => {
  const { type } = props;
  const [list, setList] = useState([]);
  const [pageNum, setNumber] = useState({ pageNum: 1 });
  const [HasNextPage, setHasNextPage] = useState(true);
  const [loading, setLoading] = useState(false)

  useDidShow(() => {
    setNumber({ pageNum: 1 })
  })

  useEffect(() => {
    if (pageNum.pageNum) {
      getList();
    }
  }, [pageNum]);

  const getList = () => {
    setLoading(true)
    setHasNextPage(false);
    getOrderSub({
      ...pageNum,
      pageSize: 10,
      isVerified: '',
      ...(type !== undefined ? dict[type] : {}),
    }).then((res) => {
      setList(
        pageNum.pageNum === 1 ? res.records || [] : list.concat(res.records || [])
      );
      setHasNextPage(res.current < res.pages);
      setLoading(false)

    }).catch(e => {
      setLoading(false)
    })
  };

  const pageLoadMore = () => {
    // 页面上拉加载更多
    if (HasNextPage) {
      const num = pageNum.pageNum + 1
      setNumber({ pageNum: num });
    }
  };

  const [showCutover, setShowCutover] = useState(false)

  const onClose = () => {
    setShowCutover(false)
  }
  const [ite, setItem] = useState({})
  const show = (val) => {
    setItem(val)
  }
  const slideButtonTap = (e) => {
    deleteOrder(e.orderId).then(() => {
      Taro.showToast({
        title: '删除订单成功',
        icon: 'none',
      })
      setNumber({ pageNum: 1 })
    })
  }

  const handleFinishEvaluate = () => {
    // 触发页面刷新
    setNumber({ pageNum: 1 })
    setShowCutover(false)
  }

  return (
    <SpinBox loading={loading}>
      <scroll-view
        scrollY
        style={{ height: '100%' }}
        onscrolltolower={pageLoadMore}
      >
        {
          list.length == 0 ?
            <NoData /> :
            <view className='complete-boxs'>
              <AlreadyUsed showCutover={showCutover} maskClosable={showCutover} onClose={onClose} onFinish={handleFinishEvaluate} item={ite} />
              {list.map((item, index) => {
                /* 待支付 */
                if (item.status === 0) {
                  return (
                    <view key={`${type}-${item.orderId}`}  >
                      <OrderCard item={item} handeDelete={slideButtonTap} />
                    </view>
                  );
                }
                /* 已使用 */
                else if (item.isVerified == 1) {
                  return (
                    <view key={`${type}-${item.orderId}`}>
                      <OrderCard item={item} setShowCutover={setShowCutover} show={show} />
                    </view>
                  );
                }
                /* 待核销 */
                else {
                  return (
                    <view key={`${type}-${item.orderId}`}>
                      <OrderCard item={item} />
                    </view>
                  );
                }
              })}
              <view className='foot'>这是我的底线</view>
            </view>
        }
      </scroll-view>
    </SpinBox>
  )
};
