import Taro, { useDidShow } from '@tarojs/taro'
import { View, Image } from '@tarojs/components';
import ToggleRole from '@/components/ToggleRole'

import see from '@/assets/icons/landlord/lookPerson.png'
import share from '@/assets/icons/landlord/shareLink.png'
import del from '@/assets/icons/landlord/delete.png'
import addImg from '@/assets/icons/landlord/add.png'
import copyRoomImg from '@/assets/icons/landlord/copyroom.png'
import React, { useState, useEffect, useRef, useImperativeHandle, useMemo } from 'react'
import { getRoomList, deleteRoom, copyRoom } from '@/services/landlord'
import Spin3 from '@/components/Spin/Spin3';
import List from '@/components/List';
import Picker from '@/components/Picker'
import SearchBar from '@/components/SearchBar'
import ShareRoom from '../shareRoom/ShareRoom.jsx'
import ShareCard from '../shareCard/shareCard'
import './houseManage.less'


export default React.forwardRef((props, ref) => {
  const { hotel, hotelList, onHotelChange, isBind } = props
  const [detail, setDetail] = useState([])
  const [search, setSearch] = useState()

  const queryParams = useMemo(() => ({
    hotelId: hotel.hotelId,
    roomName: search
  }), [hotel.hotelId, search])

  const shareDataRef = useRef()

  // 判断是否首次加载
  const mounted = useRef(false)

  const handelClick = () => {
    Taro.navigateTo({ url: `/hotel/pages/landlord/addRoom/addRoom?hotelId=${hotel.hotelId}&hotelName=${hotel.hotelName}` });
  }
  const handelDelete = (val) => {
    Taro.showModal({
      title: '提示',
      content: `确认删除${val.roomName}?`,
      success: function (res) {
        if (res.confirm) {
          deleteRoom(val.roomId).then(() => {
            Taro.showToast({
              title: '删除房源成功',
              icon: 'none',
            })
            getRoomList({ hotelId: hotel.hotelId }).then((vals) => {
              setDetail(vals.records || [])
            })
          })
        }
      }
    })
  }
  const handelDetail = (val) => {
    Taro.navigateTo({ url: `/hotel/pages/landlord/addRoom/addRoom?hotelId=${hotel.hotelId}&hotelName=${hotel.hotelName}&roomId=${val.roomId}` });
  }

  const [showCutover, setShowCutover] = useState(false)
  const [showCard, setShowCard] = useState(false)
  const [room, setRoom] = useState({})
  const ShowMoldeOn = (rooms) => {
    setRoom(rooms)
    setShowCutover(true)
  }
  const onClose = () => {
    setShowCutover(false)
  }
  const onClose2 = () => {
    setShowCard(false)
  }
  //切换民宿
  const handleHotelChange = (hotelId, current) => {
    onHotelChange(current)
  }

  useEffect(() => {
    //首次加载页面时
    if (!mounted.current && hotel.hotelId) {
      getRoomList({ hotelId: hotel.hotelId }).then((res) => {
        setDetail(res.records || [])
        mounted.current = true
      })
    }
  }, [hotel?.hotelId])

  //当前页面切换到前台时
  useDidShow(() => {
    if (mounted.current) {
      getRoomList({ hotelId: hotel.hotelId, roomName: search, pageSize: '500' }).then((res) => {
        setDetail(res.records || [])
      })
    }
  })
  //分享房源
  useImperativeHandle(ref, () => ({
    getShareMessage: () => {
      const { shareImage, roomOrderId } = shareDataRef.current
      setShowCard(false)
      return {
        title: `欢迎来到${room.roomName}`,
        path: `/pages/index/index?tab=1&roomId=${room.roomId}&roomOrderId=${roomOrderId}&fromType=hotel&recommender=${hotel.hotelId}`,
        imageUrl: shareImage,
      }
    }
  }))

  const handleFinish = (val) => {
    shareDataRef.current = val
    setShowCutover(false)
    // 打开分享弹窗
    setShowCard(true)
  }
  //查看入住人
  const handelOrder = (val) => {
    Taro.navigateTo({ url: `/hotel/pages/landlord/roomOrder/roomOrder?roomId=${val.roomId}&roomName=${val.roomName}&hotelId=${hotel.hotelId}&ClickManually=ClickManually` });
  }

  const onSearch = (e) => {
    if (e.detail.value == '') {
      setSearch()
      getRoomList({ hotelId: hotel.hotelId }).then((res) => {
        setDetail(res.records || [])
      })
    }
    else {
      setSearch(e.detail.value)
      getRoomList({ hotelId: hotel.hotelId, roomName: e.detail.value }).then((res) => {
        setDetail(res.records || [])
      })
    }
  }
  //本店指南
  const [loading, setLoading] = useState(false)
  const handelCopy = (e, val) => {
    //阻止冒泡不允许执行父元素的点击事件
    e.stopPropagation()
    setLoading(true)
    let copy = 0
    detail.map((item, index) => {
      if (item.roomId === val.roomId) {
        copy = index
      }
    })
    copyRoom(val.roomId).then((res) => {
      setLoading(false)
      Taro.showToast({
        title: '复制房源成功',
        icon: 'none',
      })
      setDetail([...detail.slice(0, copy), res, ...detail.slice(copy)])
    })
  }
  return (
    <View style={{ padding: '0 30rpx', height: '100%', display: 'flex', flexDirection: 'column' }}>
      <View style={{ flex: 'none' }}>
        <Spin3 show={loading} />
      </View>
      <View style={{ flex: 'none' }}>
        <view className='storeName'>店名：<Picker style={{ display: 'inline-block' }} placeholder='请选择民宿' value={hotel?.hotelId} kv={['hotelName', 'hotelId']} dicts={hotelList} onChange={handleHotelChange} /></view>
        <view className='User-info-cutover-normal'>
          <ToggleRole role='hotel' isBind={isBind} />
        </view>
      </View>
      <View style={{ flex: 'none' }}>
        <SearchBar placeholder='请输入房源名搜索' onBlur={onSearch} />
      </View>
      <View style={{ flex: 'none' }}>
        <ShareRoom showCutover={showCutover} onClose={onClose} room={room} onFinish={handleFinish} />
        <ShareCard showCutover={showCard} onClose={onClose2} />
      </View>
      <View style={{ flex: '1', overflow: 'hidden' }}>
        <List
          style={{ height: '100%' }}
          request={getRoomList}
          params={queryParams}
          onDataChange={setDetail}
          refresherEnabled={false}
          noData='暂无房源信息'
        >
          <view className='waterfall'>
            {
              detail.map((item, index) =>
                <view className='houseCard' key={index}>
                  <View className='houseName' onClick={() => handelDetail(item)}>{item.roomName || ''}<Image src={copyRoomImg} onClick={(e) => handelCopy(e, item)} /></View>
                  <view className='operation'>
                    <view onClick={() => handelOrder(item)}><image src={see} />查看入住人</view>
                    <view onClick={() => ShowMoldeOn(item)}><image src={share} />分享链接</view>
                    <view onClick={() => handelDelete(item)}><image src={del} />删除房源</view>
                  </view>
                </view>)
            }
          </view>
        </List>
      </View>
      <View className='addHouse' onClick={handelClick} style={{ flex: 'none' }}>
        <Image className='addImg' src={addImg} />添加房源
      </View>
    </View>
  )
})