import { useState, useMemo } from 'react'
import Taro from '@tarojs/taro'
import { View, Image } from '@tarojs/components';
import eyes from '@/assets/icons/shopKeeper/eyesON.png'
import ceyes from '@/assets/icons/shopKeeper/eyesOFF.png'
import sImg from '@/assets/icons/landlord/money2.png'
import formatTime from "@/utils/formatTime";
import formatPrice from '@/utils/formatPrice'
import { getAccountLogList } from '@/services/landlord'
import NoData from '@/components/NoData'
import List from '@/components/List';
import './income.less'


const getList = id => params => getAccountLogList(id, params)

export default (props) => {
  const { hotel, account } = props

  const queryParams = useMemo(() => ({}), [])

  const fetchAPI = useMemo(() => account.accountId ? getList(account.accountId) : undefined, [account?.accountId])

  const [isyear, setYear] = useState(true)
  const [isMomth, setMonth] = useState(false)
  const handleYear = () => {
    isyear ? setYear(false) : setYear(true)
  }
  const handleMonth = () => {
    isMomth ? setMonth(false) : setMonth(true)
  }
  return (
    <view style={{ padding: '30rpx', height: '100%',display:'flex',flexDirection:'column' }}>
      <view className='storexx' style={{flex:'none'}}>
        <view className='storeName'>店名：{hotel.hotelName}</view>
        <view className='money'>
          <view className='sleft'>
            <view className='lword'>全年收入（税前）</view>
            <view className='yearMoney'>
              <text>{isyear ? formatPrice(account?.amounts) : '******'}</text>元
              <image className='micon' src={isyear ? eyes : ceyes} onClick={handleYear} />
            </view>
          </view>
          <view className='line' />
          <view className='sright'>
            <view className='rword'>当月收入（税前）</view>
            <view className='monthMoney'>
              <text>{isMomth ? formatPrice(account?.currentCharges) : '******'}</text>元
              <image className='micon2' src={isMomth ? eyes : ceyes} onClick={handleMonth}></image>
            </view></view>
        </view>
      </view>
      <view className='title' style={{flex:'none'}}>推广收入记录</view>
      <View style={{flex:1,overflow:'hidden'}}>
        <List
          style={{ height: '100%' }}
          request={fetchAPI}
          params={queryParams}
          noData={<NoData />}
          refresherEnabled={false}
          render={({ item, index }) => (
            <view className='spreadCard' key={index}>
              <view className='card'>
                <view className='spreadTime'>时&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;间：<text>{formatTime(item.createDate, 'yyyy/MM/dd hh:mm:ss')}</text></view>
                <view className='spreadMoney'>收入金额：<text>{parseFloat((item.amount / 100).toFixed(2))}</text>元</view>
                <image className='spreadImg' src={sImg} />
              </view>
            </view>
          )}
        >
        </List>
      </View>
    </view>
  )
}