import withLayout from '@/layouts'
import React, { useState, useEffect, useMemo } from 'react'
import CustomNav from '@/components/CustomNav'
import Taro from '@tarojs/taro'
import { useModel } from '@/store'
import copy from '@/assets/icons/landlord/copy.png'
import { View, Label, Image } from '@tarojs/components'
import List from '@/components/List';
import { getRoomOrderList, getHotelDetail } from '@/services/landlord'
import './roomOrder.less'


export default withLayout((props) => {
  const { hotelId, roomId, roomName, ClickManually } = props.router.params
  const [detail, setDetail] = useState([])
  const { setHotel } = useModel('hotel')

  const queryParams = useMemo(() => ({
    roomId: roomId
  }), [roomId])

  useEffect(() => {
    if (hotelId) {
      getHotelDetail(hotelId).then((res) => {
        setHotel(res)
      })
    }
  }, [hotelId])

  const CopyName = (val) => {
    Taro.setClipboardData({
      data: val,
      success: e => {
        Taro.showToast({
          title: '姓名已复制',
          icon: 'success',
          duration: 2000,
        })
      }
    })
  }

  const CopyPhone = (val) => {
    Taro.setClipboardData({
      data: val,
      success: e => {
        Taro.showToast({
          title: '电话已复制',
          icon: 'success',
          duration: 2000,
        })
      }
    })
  }

  return (
    <View className='page-index'>
      {
        !ClickManually ? <view className='index-navbar'>
          <CustomNav noback title={roomName ? decodeURIComponent(roomName) : '房间名'} />
        </view> : <view className='index-navbar'>
          <CustomNav title={roomName ? decodeURIComponent(roomName) : '房间名'} />
        </view>
      }
      <View className='index-container'>
        <List
          style={{ height: '100%' }}
          request={getRoomOrderList}
          params={queryParams}
          onDataChange={setDetail}
          refresherEnabled={false}
          noData={<View style={{ padding: '15px 30px' }}><View className='houseCard'>暂无入住人数据</View></View>}
        >
          {
            detail.map((item, index) =>
              <View style={{ padding: '15px 30px' }}>
                <View className='houseCard' key={index}>
                  {
                    (item.personList || []).map((item2, inx) =>
                      <View className='operation' key={inx}>
                        <View style={{ display: 'inline-block' }} onClick={() => CopyName(item2.customerName)}>
                          <Label>{item2.customerName}</Label>
                          <Image src={copy} />
                        </View>
                        <View style={{ display: 'inline-block', marginLeft: '40rpx' }} onClick={() => CopyPhone(item2.customerPhone)}>
                          <Label>{item2.customerPhone}</Label>
                          <Image src={copy} />
                        </View>
                      </View>
                    )
                  }
                  <View className='operation'>入住时间：{item.startDate}  -  {item.endDate}</View>
                </View>
              </View>
            )
          }
        </List>
      </View>
    </View>
  )
})