
import { useMemo } from 'react'
import Taro from '@tarojs/taro'
import { useModel } from '@/store'
import { getQueryString } from '@/utils'
import useRouter from '@/utils/hooks/useRouter'
import useTrackPage from '@/utils/hooks/useTrackPage'
import useShareOpen from '@/utils/hooks/useShareOpen'
import Loading from './Loading'
import { getPageBy, getIndexPageOf } from '../routes'

export default (Child) => (props) => {
  const location = Taro.getStorageSync('location')

  const { person } = useModel('person')
  const router = useRouter()

  // 埋点页面访问
  const trackPageData = {
    page: router.path,
    params: getQueryString(router.params),
    location,
  }
  useTrackPage(trackPageData)

  // 打开分享
  useShareOpen(person?.personId, router.params.shareId)

  // 确保人员信息到位, 确保二维码解析结束
  const loading = !person?.personRole || (router.params.scene && !router.params.parseQRFinished);

  // 校验人员角色及页面是否对应
  const jumpPage = useMemo(() => {
    const personRole = person?.personRole;
    if (!personRole) return;

    const isNormalPerson = personRole === 'normal'

    const currentPage = getPageBy(router.path)
    let indexPage = `pages/index/index`
    if (!isNormalPerson) {
      const { page } = getIndexPageOf(personRole);
      indexPage = `${personRole}/${page}`
    }

    const isMatched = isNormalPerson ?
      // 如果是普通客户, page.root 应该是空的
      !currentPage.root :
      // 其他角色, 应该是对应的
      currentPage.root === personRole


    // 如果对应上, 就不跳转
    return isMatched ? undefined : indexPage

  }, [router.path, person?.personRole])

  if (jumpPage) {
    // 注意此处跳转是没有加上原来的页面参数的
    Taro.reLaunch({
      url: `/${jumpPage}`,
    })
  }


  return loading ? <Loading /> : <Child {...props} person={person} router={router} location={location} />

}
