import Taro, { useDidShow } from '@tarojs/taro'
import { Image, Button, View } from '@tarojs/components'
import SpinBox from "@/components/Spin/SpinBox";
import formatTime from '@/utils/formatTime'
import withLayout from '@/layouts'

import { useState, useEffect } from "react";
import SlideView from '@/components/SlideView';
import editImg from '@/assets/icons/Travel/editimg.png'
import CustomNav from '@/components/CustomNav'
import { getTravelMine, deleteTravel } from '@/services/travel'

import './style.less'

export default withLayout((props) => {

  const [loading, setLoading] = useState(false)

  //删除
  const handelDelete = (e) => {
    Taro.showModal({
      title: '提示',
      content: '确定要删除吗',
      success: function (res) {
        if (res.confirm) {

          deleteTravel(e.travelId).then(r => {
            getList()

            Taro.showToast({
              title: '删除成功',
              icon: 'none',
              duration: 1000
            })

          })

        } else if (res.cancel) {
          getList()


        }
      }
    })

  }
  const handelEdit = (item) => {

    Taro.navigateTo({ url: `/pages/Travel/Edit/index?id=${item.travelId}&dayNum=${item.dayNum}&travelId=${item.travelId}` })
  }

  const [travelMine, setTravelMine] = useState([])
  const getList = () => {
    getTravelMine({ pageNum: 1, pageSize: 99, }).then(e => {
      setTravelMine(e.records)


    })
  }
  useDidShow(() => getList())

  useEffect(() => {
    getList()

  }, [])
  return (
    <View className='page-index box-content'>
      <View className='index-navbar'>
        <CustomNav title='我的行程' />
      </View>
      <View className='index-container'>
        <SpinBox loading={loading}>
          <scroll-view
            scrollY
            style='height: 100%;'
          >
            <View className='View-box'>
              {
                travelMine.map((item, index) =>

                  <SlideView key={index} del onDelete={() => handelDelete(item)} className='myTravel'>
                    <View className='View-box-Card' onClick={() => handelEdit(item)}>
                      <View className='bottom'>
                        <View className='travelName'>{item.title}</View>
                        <Image src={editImg} className='edit'></Image>
                      </View>
                      <View className='bottom'>
                        <View className='travelDay'>行程时间：{item.dayNum}天</View>
                        <View className='travelDate'>创建时间：{formatTime(item.createDate, "yyyy/MM/dd")}</View>
                      </View>
                    </View>
                  </SlideView>

                )
              }

              <View className='foot'>这是我的底线</View>
            </View>
          </scroll-view>
        </SpinBox>
      </View>
    </View >
  )
})