import Taro from "@tarojs/taro"
import { useEffect, useState } from "react"
import CustomNav from '@/components/CustomNav'
import withLayout from '@/layouts'
import { getTaRoom, goToRoomForm, personSubmit } from '@/services/taRoom​'
import { getHotelDetail } from '@/services/landlord'
import { View } from '@tarojs/components';
import { withSubscribeMessage } from "@/utils/subscribeMessage"
import { TPL_MESSAGE_HOTEL_CHECK_OUT } from '@/utils/constants'
import RoomForm from './components/RoomForm'
import './style.less'


export default withLayout((props) => {
  const { router, person } = props
  const { roomId, roomOrderId, status } = router.params
  const [taRoomContent, setTaRoomContent] = useState([])
  const [orderContent, setOrderContent] = useState([])
  const [titleLogo, settitleLogo] = useState('none')
  const [loading, setLoading] = useState(false)

  const { hotelId } = orderContent
  const CarNumber = orderContent?.personNum
  const [formData, setFormData] = useState([])

  const handleChange = (e, inx) => {
    formData[inx] = e;
    setFormData([...formData])
  }

  const handleSubmit = (e) => {
    setLoading(true)

    // 订阅消息
    withSubscribeMessage([TPL_MESSAGE_HOTEL_CHECK_OUT], () => {
      for (let i = 0, len = formData.length; i < len; i++) {
        const item = formData[i];
        if (!item.customerName || !item.customerPhone) {
          Taro.showToast({
            title: '手机号或姓名不能为空',
            icon: 'none',
          })
          return;
        }
      }
      personSubmit(roomOrderId, formData).then(a => {
        // Taro.navigateBack({
        //   delta: 1
        // })
        setLoading(false)

        Taro.reLaunch({
          url: `/pages/index/index?tab=1&roomId=${roomId}`
        })
      })
    })

  }

  useEffect(() => {
    getTaRoom(roomId).then((res) => {
      setTaRoomContent(res)
    })
    goToRoomForm(roomOrderId).then((res) => {
      setOrderContent(res)
    })
    getHotelDetail(hotelId).then((e) => {
      settitleLogo(e?.logo || 'none')
    })
  }, [hotelId, roomId, roomOrderId])

  const FormCard = new Array(CarNumber).fill(0)
  return (
    <view className='page-index'>
      <view className='index-navbar'>
        <CustomNav logo={titleLogo} title={taRoomContent?.roomName} />
      </view>
      <View className='index-container'>
        <scroll-view scroll-y style='height: 100%;' >
          {
            FormCard.map((_, index) => {
              return (
                <RoomForm key={(index)} onChange={(e) => handleChange(e, index)} />
              )
            })
          }
          <button className='button-OK' onClick={handleSubmit} loading={loading} disabled={loading} >确定</button>
        </scroll-view>
      </View>
    </view>
  )
})