
/**
 * queryString 转 object
 * @param {*} queryStr 
 * @returns 
 */
export function parseQueryString(queryStr) {
  if (!queryStr) {
    return;
  }

  const params = queryStr.split('&').reduce((acc, str) => {
    if (!str) return acc;

    const kv = str.split('=')
    if (kv.length !== 2) return acc;

    const key = decodeURIComponent(kv[0])
    const val = decodeURIComponent(kv[1])

    return {
      ...acc,
      [key]: val,
    }
  }, {});
  return params;
}

/**
 * object 转 queryStr
 * @param {*} params 
 * @returns 
 */
export function getQueryString(params) {
  if (!params) return ;

  const keys = Object.keys(params)
  const arr = keys.map((key) => {
    const val = params[key]
    if (val === null || val === undefined) return false;

    return `${key}=${encodeURIComponent(val)}`
  })

  return arr.filter(Boolean).join('&')
}

/**
 * 随机串
 * @param {*} prefix 
 * @returns 
 */
export function random(prefix) {
  const s = Math.random().toString(36).substring(2)

  return prefix ? `${prefix}-${s}` : s
}

/**
 * 压缩图片
 * @param {*} url 
 * @returns 
 */
export function compressImage(url, typ) {
  if (!url) return url;

  // GIF 不压缩
  if (url.indexOf('.gif') > -1) return url;

  const style = typ || 'cmp80'

  // eslint-disable-next-line no-undef
  if (url.indexOf(OSS) > -1) {
    return `${url}?x-oss-process=style/${style}`.replace('http://', 'https://')
  }

  return url;
}
